changeset 1799:50e9cca3fe7b

Fixed X11 support on Mac OS X Universal build
author Sam Lantinga <slouken@libsdl.org>
date Wed, 10 May 2006 05:17:58 +0000
parents 49b4b8413734
children cc6bea4bb90d
files build-scripts/fatbuild.sh configure.in
diffstat 2 files changed, 16 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/configure.in	Wed May 10 04:05:46 2006 +0000
+++ b/configure.in	Wed May 10 05:17:58 2006 +0000
@@ -833,6 +833,8 @@
             if test x$ac_cv_func_shmat != xyes; then
                 X_CFLAGS="$X_CFLAGS -DNO_SHARED_MEMORY"
             fi
+            CFLAGS="$CFLAGS $X_CFLAGS"
+            LDFLAGS="$LDFLAGS $X_LIBS"
 
             AC_DEFINE(SDL_VIDEO_DRIVER_X11)
             SOURCES="$SOURCES $srcdir/src/video/x11/*.c"
--- a/build-scripts/fatbuild.sh	Wed May 10 04:05:46 2006 +0000
+++ b/build-scripts/fatbuild.sh	Wed May 10 05:17:58 2006 +0000
@@ -10,7 +10,12 @@
 # Generic, cross-platform CFLAGS you always want go here.
 CFLAGS="-O3 -g -pipe"
 
-# PowerPC compiler flags (10.2 runtime compatibility)
+# PowerPC configure flags (10.2 runtime compatibility)
+# We dynamically load X11, so using the system X11 headers is fine.
+CONFIG_PPC="--build=`uname -p`-apple-darwin --host=powerpc-apple-darwin \
+--x-includes=/usr/X11R6/include --x-libraries=/usr/X11R6/lib"
+
+# PowerPC compiler flags
 CC_PPC="gcc-3.3 -arch ppc"
 CXX_PPC="g++-3.3 -arch ppc"
 CFLAGS_PPC=""
@@ -26,7 +31,12 @@
 -F/Developer/SDKs/MacOSX10.2.8.sdk/System/Library/Frameworks \
 -Wl,-syslibroot,/Developer/SDKs/MacOSX10.2.8.sdk"
 
-# Intel compiler flags (10.4 runtime compatibility)
+# Intel configure flags (10.4 runtime compatibility)
+# We dynamically load X11, so using the system X11 headers is fine.
+CONFIG_X86="--build=`uname -p`-apple-darwin --host=i386-apple-darwin \
+--x-includes=/usr/X11R6/include --x-libraries=/usr/X11R6/lib"
+
+# Intel compiler flags
 CC_X86="gcc-4.0 -arch i386"
 CXX_X86="g++-4.0 -arch i386"
 CFLAGS_X86="-mmacosx-version-min=10.4"
@@ -158,7 +168,7 @@
 #
 if test x$configure_ppc = xyes; then
     (cd build/ppc && \
-     sh ../../configure --build=`uname -p`-apple-darwin --host=powerpc-apple-darwin CC="$CC_PPC" CXX="$CXX_PPC" CFLAGS="$CFLAGS $CFLAGS_PPC" CPPFLAGS="$CPPFLAGS_PPC" LDFLAGS="$LFLAGS_PPC") || exit 2
+     sh ../../configure $CONFIG_PPC CC="$CC_PPC" CXX="$CXX_PPC" CFLAGS="$CFLAGS $CFLAGS_PPC" CPPFLAGS="$CPPFLAGS_PPC" LDFLAGS="$LFLAGS_PPC") || exit 2
 fi
 if test x$make_ppc = xyes; then
     (cd build/ppc && ls include && make -j$NJOB) || exit 3
@@ -169,7 +179,7 @@
 #
 if test x$configure_x86 = xyes; then
     (cd build/x86 && \
-     sh ../../configure --build=`uname -p`-apple-darwin --host=i386-apple-darwin CC="$CC_X86" CXX="$CXX_X86" CFLAGS="$CFLAGS $CFLAGS_X86" CPPFLAGS="$CPPFLAGS_X86" LDFLAGS="$LFLAGS_X86") || exit 2
+     sh ../../configure $CONFIG_X86 CC="$CC_X86" CXX="$CXX_X86" CFLAGS="$CFLAGS $CFLAGS_X86" CPPFLAGS="$CPPFLAGS_X86" LDFLAGS="$LFLAGS_X86") || exit 2
 fi
 if test x$make_x86 = xyes; then
     (cd build/x86 && make -j$NJOB) || exit 3